@@ -93,25 +93,40 @@ def read(type, settings):
 
 
 def __read_csv(settings: dict):
-    df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], parse_dates=[i for i in range(len(pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"]).columns))])
-    #df = normalize_columns(df)
-    #df.to_parquet(settings["parquet"])
+    #df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], parse_dates=[i for i in range(len(pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"]).columns))])
+    
+    # Handle thousands
+    if settings["thousands"] == "None":
+       settings["thousands"] = None
+
+    # Read source file
+    df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], thousands=settings["thousands"])
+
+    # Detect if any column is a date-time
+    for col in df.columns:
+        if df[col].dtype == 'object':
+            try:
+                df[col] = pd.to_datetime(df[col])
+            except ValueError:
+                pass
+
+    # Exec custom post-processing
+    if "processing" in settings and settings["processing"] != "" and settings["processing"] != None:
+        exec(settings["processing"])
+
     return df
 
 def __read_excel(settings: dict):
     df = pd.read_excel(settings["path"], parse_dates=[i for i in range(len(pd.read_excel(settings["path"]).columns))])
-    #df = normalize_columns(df)
-    #df.to_parquet(settings["parquet"])
+
     return df
 
 def __read_gsheet(settings: dict):
     df = read_gsheet(settings["url"])
-    #df = normalize_columns(df)
-    #df.to_parquet(settings["parquet"])
+
     return df
 
 def __read_hubspot(settings: dict):
     df = read_hubspot_contacts(settings["fields"]["token"])
-    #df = normalize_columns(df)
-    #df.to_parquet(settings["parquet"])
+
     return df
\ No newline at end of file
