@@ -177,7 +177,7 @@ class SQLSorting(Enum):
 @dataclass
 class Sorting:
     field: str
-    order: SQLSorting
+    order: Union[SQLSorting,str]
 
 
 @dataclass
