@@ -3,6 +3,7 @@ import askdata.insight as ins
 from datetime import datetime
 import json
 import random
+from pandas import DataFrame
 
 if __name__ == '__main__':
     # agent a
@@ -23,7 +24,7 @@ if __name__ == '__main__':
 
     # get agent
     agent = Agent(askdata, 'SDK_TEST')
-    agent = Agent(askdata, agent_name='SDK_TESTER')
+    agent = Agent(askdata, agent_name='SDK_TEST')
     agent = Agent(askdata, agent_id='2ed8390e-b542-4f62-82b8-c8f1b620ef15')
     #agent = Agent(askdata, agent_name='SDK_TEST')
 
@@ -32,3 +33,4 @@ if __name__ == '__main__':
     # ------------------------------ send query NL to agent  -----------------------------------
     df = agent.ask('incassi per agenzia per canale')
     print(df.head(5))
+
